@@ -9,7 +9,7 @@ pub enum CaptureKey {
 
 impl Eq for CaptureKey {}
 
-pub(crate) fn captures_utf8(input: &[u8], regex: &str) -> HashMap<CaptureKey, String> {
+pub fn captures_utf8(input: &[u8], regex: &str) -> HashMap<CaptureKey, String> {
     let mut captures = HashMap::new();
     use regex::Regex;
     let re = Regex::new(regex).expect("valid regex");
@@ -34,14 +34,14 @@ pub(crate) fn captures_utf8(input: &[u8], regex: &str) -> HashMap<CaptureKey, St
     captures
 }
 
-pub(crate) fn regex_match_utf8(input: &[u8], regex: &str) -> (bool, String) {
+pub fn regex_match_utf8(input: &[u8], regex: &str) -> (bool, String) {
     use regex::Regex;
     let re = Regex::new(regex).expect("compiled regex");
     let text = String::from_utf8_lossy(input);
     (re.is_match(&text), text.into_owned())
 }
 
-pub(crate) fn regex_match_bytes(input: &[u8], regex: &str) -> (bool, String) {
+pub fn regex_match_bytes(input: &[u8], regex: &str) -> (bool, String) {
     use regex::bytes::Regex;
     let re = Regex::new(regex).expect("compiled regex");
     (
@@ -49,3 +49,23 @@ pub(crate) fn regex_match_bytes(input: &[u8], regex: &str) -> (bool, String) {
         String::from_utf8_lossy(input).into_owned(),
     )
 }
+
+#[cfg(test)]
+#[cfg(unix)]
+mod test {
+    use super::*;
+
+    #[test]
+    fn captures() {
+        use CaptureKey::*;
+
+        let captures = captures_utf8(b"Hello World!", "(?P<first>[^ ]*) (?P<second>[^ ]*)");
+
+        assert_eq!(captures[&Index(0)], "Hello World!");
+        assert_eq!(captures[&Index(1)], "Hello");
+        assert_eq!(captures[&Index(2)], "World!");
+        assert_eq!(captures[&Name(String::from("first"))], "Hello");
+        assert_eq!(captures[&Name(String::from("second"))], "World!");
+    }
+
+}
